# typer-awake

This cli will just be a clone of [Wakepy's](https://wakepy.readthedocs.io/stable/cli-api.html) CLI. Just adding Rich to it so it's more explicit which mode client is in.

Not TESTED! Use at your own risk.
